@@ -19,11 +19,13 @@
 
 #include "idjob.h"
 
+#include <KLocalizedString>
+
 #include "job_p.h"
 #include "message_p.h"
 #include "session_p.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
     class IdJobPrivate : public JobPrivate
     {
@@ -35,10 +37,10 @@ namespace KIMAP2
     };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 IdJob::IdJob(Session *session)
-    : Job(*new IdJobPrivate(session, "Id"))
+    : Job(*new IdJobPrivate(session, i18n("Id")))
 {
 }
 
@@ -57,19 +59,17 @@ void IdJob::doStart()
     Q_D(IdJob);
     QByteArray command = "ID";
     command += " (";
-
-    QMapIterator<QByteArray, QByteArray> i(d->fields);
-    while (i.hasNext()) {
-        i.next();
-        command += "\"" + i.key() + "\" \"" + i.value() + "\" ";
+    foreach (const QByteArray &name, d->fields.keys()) {
+        command += "\"" + name + "\" \"" + d->fields.value(name) + "\" ";
     }
     command.chop(1);
     command += ")";
-    d->sendCommand(command, {});
+    d->tags << d->sessionInternal()->sendCommand(command);
 }
 
 void IdJob::handleResponse(const Message &response)
 {
+    Q_D(IdJob);
     if (handleErrorReplies(response) == NotHandled) {
         // Ignore the response
     }
